##  Viewing Aggregated Items
You can view aggregated items that were consolidated into a single fact sheet during synchronization with ServiceNow. To do that, follow these steps:
  1. Navigate to an IT component fact sheet of the software subtype.
  2. On the right-side pane of the fact sheet page, under Integrations, click the ServiceNow tile that shows the count of aggregated items.
![Navigating to Aggregated Items from the Fact Sheet Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275313d57a441014ae7dd0b0feaed97b_LowRes.png)
Navigating to Aggregated Items from the Fact Sheet Page


In the overlay that appears, you can view all software modules that were aggregated into the fact sheet.
![Viewing Aggregated Items](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f4a4f7a441014bb8ea6557f53ab86_LowRes.png)
Viewing Aggregated Items
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
